==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/ImageCellInfoDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CellInfoDescriptionMetadata } from "./CellInfoDescriptionMetadata";
import { ImageCellInfoDescription } from "./ImageCellInfoDescription";
/**
 * @hidden
 */
var ImageCellInfoDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ImageCellInfoDescriptionMetadata, _super);
    function ImageCellInfoDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ImageCellInfoDescriptionMetadata.b = function (a) {
        if (ImageCellInfoDescriptionMetadata.a == null) {
            ImageCellInfoDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ImageCellInfoDescriptionMetadata.c(ImageCellInfoDescriptionMetadata.a);
        }
        if (a.k(ImageCellInfoDescriptionMetadata.a)) {
            return;
        }
        a.ab(ImageCellInfoDescriptionMetadata.a);
    };
    ImageCellInfoDescriptionMetadata.c = function (a) {
        CellInfoDescriptionMetadata.c(a);
        a.item("ImagePath", "String");
        a.item("ImageStretchOption", "ExportedType:string:ImageStretchOptions");
        a.item("ImageStretchOption@names", "Uniform;Fill;None");
        a.item("ImageResourceType", "ExportedType:string:ImageResourceType");
        a.item("ImageResourceType@names", "Unspecified;LocalResource;LocalAsset;EmbeddedResource;RemoteResource");
    };
    ImageCellInfoDescriptionMetadata.d = function (a) {
        ImageCellInfoDescriptionMetadata.b(a);
        a.ad("ImageCellInfo", function () { return new ImageCellInfoDescription(); });
        a.ac("ImageCellInfo", ImageCellInfoDescriptionMetadata.a);
    };
    ImageCellInfoDescriptionMetadata.$t = markType(ImageCellInfoDescriptionMetadata, 'ImageCellInfoDescriptionMetadata');
    ImageCellInfoDescriptionMetadata.a = null;
    return ImageCellInfoDescriptionMetadata;
}(Base));
export { ImageCellInfoDescriptionMetadata };

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm5/lib/ImageCellInfoDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CellInfoDescriptionMetadata } from "./CellInfoDescriptionMetadata";
import { ImageCellInfoDescription } from "./ImageCellInfoDescription";
/**
 * @hidden
 */
var ImageCellInfoDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ImageCellInfoDescriptionMetadata, _super);
    function ImageCellInfoDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ImageCellInfoDescriptionMetadata.b = function (a) {
        if (ImageCellInfoDescriptionMetadata.a == null) {
            ImageCellInfoDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ImageCellInfoDescriptionMetadata.c(ImageCellInfoDescriptionMetadata.a);
        }
        if (a.k(ImageCellInfoDescriptionMetadata.a)) {
            return;
        }
        a.ac(ImageCellInfoDescriptionMetadata.a);
    };
    ImageCellInfoDescriptionMetadata.c = function (a) {
        CellInfoDescriptionMetadata.c(a);
        a.item("ImagePath", "String");
        a.item("ImageStretchOption", "ExportedType:string:ImageStretchOptions");
        a.item("ImageStretchOption@names", "Uniform;Fill;None");
        a.item("ImageResourceType", "ExportedType:string:ImageResourceType");
        a.item("ImageResourceType@names", "Unspecified;LocalResource;LocalAsset;EmbeddedResource;RemoteResource");
    };
    ImageCellInfoDescriptionMetadata.d = function (a) {
        ImageCellInfoDescriptionMetadata.b(a);
        a.ae("ImageCellInfo", function () { return new ImageCellInfoDescription(); });
        a.ad("ImageCellInfo", ImageCellInfoDescriptionMetadata.a);
    };
    ImageCellInfoDescriptionMetadata.$t = markType(ImageCellInfoDescriptionMetadata, 'ImageCellInfoDescriptionMetadata');
    ImageCellInfoDescriptionMetadata.a = null;
    return ImageCellInfoDescriptionMetadata;
}(Base));
export { ImageCellInfoDescriptionMetadata };
